@@ -24,7 +24,6 @@
 #include "renderer.h"
 #include "settings.h"
 #include "object.h"
-#include "fontutils.h"
 
 #include <QPainter>
 #include <QPixmap>
@@ -33,6 +32,7 @@
 #include <KPixmapCache>
 #include <QSvgRenderer>
 #include <KDebug>
+#include <kfontutils.h>
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgametheme.h>
@@ -115,12 +115,12 @@ bool Renderer::loadTheme(const QString &name)
     return true;
 }
 
-QPixmap Renderer::getPart(QString frameSvgName)
+QPixmap Renderer::getPart(const QString &frameSvgName)
 {
 	return getPartOfSize(frameSvgName, p->m_partSize);
 }
 
-QPixmap Renderer::getPartOfSize(QString frameSvgName, QSize &partSize)
+QPixmap Renderer::getPartOfSize(const QString &frameSvgName, const QSize &partSize)
 {
 	QString framePixName = frameSvgName + sizeSuffix.arg(partSize.width()).arg(partSize.height());
 	QPixmap pix;
@@ -279,7 +279,7 @@ QPixmap *Renderer::getPlayField()
 	return p->m_playField;
 }
 
-QPixmap Renderer::messageBox(QString &message) {
+QPixmap Renderer::messageBox(const QString &message) {
 	int w = p->m_sceneSize.width() / 2;
 	int h = p->m_sceneSize.height() / 3;
 
@@ -288,7 +288,7 @@ QPixmap Renderer::messageBox(QString &message) {
 
 	QPainter painter(&pixmap);
 
-	int fontSize = fontUtils::fontSize(painter, message, w * 0.9, h, fontUtils::DoNotAllowWordWrap);
+	const int fontSize = KFontUtils::adaptFontSize(painter, message, w * 0.9, h, 28, 1, KFontUtils::DoNotAllowWordWrap);
 
 	painter.setPen(QColor(255, 255, 255, 220));
 	painter.setFont(QFont(QLatin1String( "Helvetica" ), fontSize, QFont::Bold));
